"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.commandNames = exports.rcOptionsTypes = void 0;
exports.cliOptionsTypes = cliOptionsTypes;
exports.help = help;
exports.handler = handler;
const cli_utils_1 = require("@pnpm/cli-utils");
const common_cli_options_help_1 = require("@pnpm/common-cli-options-help");
const config_1 = require("@pnpm/config");
const error_1 = require("@pnpm/error");
const pick_1 = __importDefault(require("ramda/src/pick"));
const render_help_1 = __importDefault(require("render-help"));
const start_1 = require("./start");
const status_1 = require("./status");
const stop_1 = require("./stop");
exports.rcOptionsTypes = cliOptionsTypes;
function cliOptionsTypes() {
    return {
        ...(0, pick_1.default)([
            'store-dir',
        ], config_1.types),
        background: Boolean,
        'ignore-stop-requests': Boolean,
        'ignore-upload-requests': Boolean,
        port: Number,
        protocol: ['auto', 'tcp', 'ipc'],
    };
}
exports.commandNames = ['server'];
function help() {
    return (0, render_help_1.default)({
        description: 'Manage a store server',
        descriptionLists: [
            {
                title: 'Commands',
                list: [
                    {
                        description: '\
Starts a service that does all interactions with the store. \
Other commands will delegate any store-related tasks to this service',
                        name: 'start',
                    },
                    {
                        description: 'Stops the store server',
                        name: 'stop',
                    },
                    {
                        description: 'Prints information about the running server',
                        name: 'status',
                    },
                ],
            },
            {
                title: 'Start options',
                list: [
                    {
                        description: 'Runs the server in the background',
                        name: '--background',
                    },
                    {
                        description: 'The communication protocol used by the server',
                        name: '--protocol <auto|tcp|ipc>',
                    },
                    {
                        description: 'The port number to use, when TCP is used for communication',
                        name: '--port <number>',
                    },
                    common_cli_options_help_1.OPTIONS.storeDir,
                    {
                        description: 'Maximum number of concurrent network requests',
                        name: '--network-concurrency <number>',
                    },
                    {
                        description: "If false, doesn't check whether packages in the store were mutated",
                        name: '--[no-]verify-store-integrity',
                    },
                    {
                        name: '--[no-]lock',
                    },
                    {
                        description: 'Disallows stopping the server using `pnpm server stop`',
                        name: '--ignore-stop-requests',
                    },
                    {
                        description: 'Disallows creating new side effect cache during install',
                        name: '--ignore-upload-requests',
                    },
                    ...common_cli_options_help_1.UNIVERSAL_OPTIONS,
                ],
            },
        ],
        url: (0, cli_utils_1.docsUrl)('server'),
        usages: ['pnpm server <command>'],
    });
}
function handler(opts, params) {
    // We can only support TCP at the moment because node-fetch does not support IPC
    opts.protocol = 'tcp';
    switch (params[0]) {
        case 'start':
            return (0, start_1.start)(opts);
        case 'status':
            return (0, status_1.status)(opts);
        case 'stop':
            return (0, stop_1.stop)(opts);
        default:
            help();
            if (params[0]) {
                throw new error_1.PnpmError('INVALID_SERVER_COMMAND', `"server ${params[0]}" is not a pnpm command. See "pnpm help server".`);
            }
            return undefined;
    }
}
//# sourceMappingURL=server.js.map