"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.stop = stop;
const util_1 = require("util");
const path_1 = __importDefault(require("path"));
const logger_1 = require("@pnpm/logger");
const server_1 = require("@pnpm/server");
const store_connection_manager_1 = require("@pnpm/store-connection-manager");
const store_path_1 = require("@pnpm/store-path");
const delay_1 = __importDefault(require("delay"));
const process_exists_1 = __importDefault(require("process-exists"));
const tree_kill_1 = __importDefault(require("tree-kill"));
const kill = (0, util_1.promisify)(tree_kill_1.default);
async function stop(opts) {
    const storeDir = await (0, store_path_1.getStorePath)({
        pkgRoot: opts.dir,
        storePath: opts.storeDir,
        pnpmHomeDir: opts.pnpmHomeDir,
    });
    const connectionInfoDir = (0, store_connection_manager_1.serverConnectionInfoDir)(storeDir);
    const serverJson = await (0, store_connection_manager_1.tryLoadServerJson)({
        serverJsonPath: path_1.default.join(connectionInfoDir, 'server.json'),
        shouldRetryOnNoent: false,
    });
    if (serverJson === null) {
        (0, logger_1.globalInfo)(`Nothing to stop. No server is running for the store at ${storeDir}`);
        return;
    }
    const storeController = await (0, server_1.connectStoreController)(serverJson.connectionOptions);
    await storeController.stop();
    if (await serverGracefullyStops(serverJson.pid)) {
        (0, logger_1.globalInfo)('Server gracefully stopped');
        return;
    }
    (0, logger_1.globalWarn)('Graceful shutdown failed');
    await kill(serverJson.pid, 'SIGINT');
    (0, logger_1.globalInfo)('Server process terminated');
}
async function serverGracefullyStops(pid) {
    if (!await (0, process_exists_1.default)(pid))
        return true;
    await (0, delay_1.default)(5000);
    return !await (0, process_exists_1.default)(pid);
}
//# sourceMappingURL=stop.js.map